Learn R Programming

kardl (version 0.1.1)

kardl_get: Function to get settings

Description

This function retrieves options from the kardl package settings.

Usage

kardl_get(...)

Value

If no arguments are provided, returns all options as a list. If one option is requested, returns its value directly. If multiple options are requested, returns a list of those options.

Arguments

...

Names of the options to retrieve. If none provided, all options are returned.

See Also

kardl_set, kardl_reset

Examples

Run this code
# Get specific options
kardl_get("criterion", "differentAsymLag")

# Get all options
# Note: In interactive use, avoid calling this directly to prevent cluttering the console.
a<-kardl_get()
a$AsymSuffix

Run the code above in your browser using DataLab