Learn R Programming

kardl (version 0.1.1)

kardl_longrun: Calculating the long-run parameters

Description

All long-run estimated parameters are standardized by dividing them by the negative of the long-run parameter of the dependent variable.

Usage

kardl_longrun(model)

Value

a list of class kardl with the following elements:

  • type: the type of the model, in this case "kardl_longrun"

  • coef: the estimated coefficients of the long-run parameters

  • delta_se: the standard errors of the long-run parameters

  • results: a data frame with the estimated coefficients, standard errors, t-values, p-values, and significance stars

  • starsDesc: a description of the significance stars used in the results

Arguments

model

the model produced by kardl

Details

This function is used to calculate the long-run parameters of a model produced by the kardl function.

It calculates the long-run multipliers and their standard errors, and returns a list containing the kardl_longrun coefficients, standard errors, and a data frame with the results.

See Also

kardl, pssf, psst

Examples

Run this code
kardl_model<-kardl(imf_example_data,
                  CPI~ER+PPI+asym(ER)+deterministic(covid)+trend,
                  mode=c(1,2,3,0))
kardl_longrun(kardl_model)

# Using magrittr
library(magrittr)

imf_example_data %>% kardl(CPI~ER+PPI+asym(ER)+deterministic(covid)+trend,
                  mode=c(1,2,3,0)) %>% kardl_longrun()

Run the code above in your browser using DataLab